Module: ClaudeMemory
- Defined in:
- lib/claude_memory.rb,
lib/claude_memory.rb,
lib/claude_memory/cli.rb,
lib/claude_memory/recall.rb,
lib/claude_memory/publish.rb,
lib/claude_memory/version.rb,
lib/claude_memory/mcp/tools.rb,
lib/claude_memory/shortcuts.rb,
lib/claude_memory/mcp/server.rb,
lib/claude_memory/core/result.rb,
lib/claude_memory/domain/fact.rb,
lib/claude_memory/core/fact_id.rb,
lib/claude_memory/hook/handler.rb,
lib/claude_memory/configuration.rb,
lib/claude_memory/domain/entity.rb,
lib/claude_memory/mcp/telemetry.rb,
lib/claude_memory/sweep/sweeper.rb,
lib/claude_memory/core/null_fact.rb,
lib/claude_memory/core/rr_fusion.rb,
lib/claude_memory/logging/logger.rb,
lib/claude_memory/core/fact_graph.rb,
lib/claude_memory/core/session_id.rb,
lib/claude_memory/domain/conflict.rb,
lib/claude_memory/hook/exit_codes.rb,
lib/claude_memory/ingest/ingester.rb,
lib/claude_memory/mcp/query_guide.rb,
lib/claude_memory/core/fact_ranker.rb,
lib/claude_memory/mcp/text_summary.rb,
lib/claude_memory/mcp/tool_helpers.rb,
lib/claude_memory/resolve/resolver.rb,
lib/claude_memory/commands/registry.rb,
lib/claude_memory/core/batch_loader.rb,
lib/claude_memory/core/scope_filter.rb,
lib/claude_memory/core/text_builder.rb,
lib/claude_memory/distill/distiller.rb,
lib/claude_memory/domain/provenance.rb,
lib/claude_memory/index/index_query.rb,
lib/claude_memory/index/lexical_fts.rb,
lib/claude_memory/recall/query_core.rb,
lib/claude_memory/sweep/maintenance.rb,
lib/claude_memory/core/relative_time.rb,
lib/claude_memory/core/result_sorter.rb,
lib/claude_memory/distill/extraction.rb,
lib/claude_memory/index/vector_index.rb,
lib/claude_memory/ingest/privacy_tag.rb,
lib/claude_memory/ingest/tool_filter.rb,
lib/claude_memory/recall/dual_engine.rb,
lib/claude_memory/store/sqlite_store.rb,
lib/claude_memory/core/concept_ranker.rb,
lib/claude_memory/core/fact_collector.rb,
lib/claude_memory/core/result_builder.rb,
lib/claude_memory/embeddings/resolver.rb,
lib/claude_memory/index/query_options.rb,
lib/claude_memory/store/retry_handler.rb,
lib/claude_memory/store/store_manager.rb,
lib/claude_memory/core/token_estimator.rb,
lib/claude_memory/core/transcript_path.rb,
lib/claude_memory/embeddings/generator.rb,
lib/claude_memory/embeddings/inspector.rb,
lib/claude_memory/mcp/error_classifier.rb,
lib/claude_memory/mcp/tool_definitions.rb,
lib/claude_memory/recall/legacy_engine.rb,
lib/claude_memory/store/schema_manager.rb,
lib/claude_memory/commands/base_command.rb,
lib/claude_memory/commands/help_command.rb,
lib/claude_memory/commands/hook_command.rb,
lib/claude_memory/commands/init_command.rb,
lib/claude_memory/core/null_explanation.rb,
lib/claude_memory/embeddings/similarity.rb,
lib/claude_memory/hook/context_injector.rb,
lib/claude_memory/hook/error_classifier.rb,
lib/claude_memory/ingest/tool_extractor.rb,
lib/claude_memory/commands/index_command.rb,
lib/claude_memory/commands/stats_command.rb,
lib/claude_memory/commands/sweep_command.rb,
lib/claude_memory/core/snippet_extractor.rb,
lib/claude_memory/distill/null_distiller.rb,
lib/claude_memory/embeddings/api_adapter.rb,
lib/claude_memory/mcp/response_formatter.rb,
lib/claude_memory/commands/doctor_command.rb,
lib/claude_memory/commands/export_command.rb,
lib/claude_memory/commands/ingest_command.rb,
lib/claude_memory/commands/recall_command.rb,
lib/claude_memory/commands/reject_command.rb,
lib/claude_memory/commands/search_command.rb,
lib/claude_memory/core/fact_query_builder.rb,
lib/claude_memory/index/index_query_logic.rb,
lib/claude_memory/commands/changes_command.rb,
lib/claude_memory/commands/checks/reporter.rb,
lib/claude_memory/commands/compact_command.rb,
lib/claude_memory/commands/db_init_command.rb,
lib/claude_memory/commands/explain_command.rb,
lib/claude_memory/commands/git_lfs_command.rb,
lib/claude_memory/commands/promote_command.rb,
lib/claude_memory/commands/publish_command.rb,
lib/claude_memory/commands/recover_command.rb,
lib/claude_memory/commands/restore_command.rb,
lib/claude_memory/commands/version_command.rb,
lib/claude_memory/hook/distillation_runner.rb,
lib/claude_memory/ingest/content_sanitizer.rb,
lib/claude_memory/ingest/transcript_reader.rb,
lib/claude_memory/mcp/instructions_builder.rb,
lib/claude_memory/resolve/predicate_policy.rb,
lib/claude_memory/commands/checks/vec_check.rb,
lib/claude_memory/embeddings/model_registry.rb,
lib/claude_memory/ingest/metadata_extractor.rb,
lib/claude_memory/mcp/setup_status_analyzer.rb,
lib/claude_memory/recall/expansion_detector.rb,
lib/claude_memory/commands/conflicts_command.rb,
lib/claude_memory/commands/serve_mcp_command.rb,
lib/claude_memory/commands/uninstall_command.rb,
lib/claude_memory/embeddings/dimension_check.rb,
lib/claude_memory/infrastructure/file_system.rb,
lib/claude_memory/recall/dual_query_template.rb,
lib/claude_memory/commands/checks/hooks_check.rb,
lib/claude_memory/commands/completion_command.rb,
lib/claude_memory/commands/embeddings_command.rb,
lib/claude_memory/mcp/handlers/query_handlers.rb,
lib/claude_memory/mcp/handlers/setup_handlers.rb,
lib/claude_memory/mcp/handlers/stats_handlers.rb,
lib/claude_memory/embeddings/fastembed_adapter.rb,
lib/claude_memory/commands/checks/distill_check.rb,
lib/claude_memory/ingest/observation_compressor.rb,
lib/claude_memory/mcp/handlers/context_handlers.rb,
lib/claude_memory/commands/checks/database_check.rb,
lib/claude_memory/commands/checks/snapshot_check.rb,
lib/claude_memory/commands/install_skill_command.rb,
lib/claude_memory/mcp/handlers/shortcut_handlers.rb,
lib/claude_memory/commands/checks/claude_md_check.rb,
lib/claude_memory/infrastructure/schema_validator.rb,
lib/claude_memory/core/embedding_candidate_builder.rb,
lib/claude_memory/infrastructure/operation_tracker.rb,
lib/claude_memory/mcp/handlers/management_handlers.rb,
lib/claude_memory/infrastructure/in_memory_file_system.rb,
lib/claude_memory/commands/initializers/database_ensurer.rb,
lib/claude_memory/commands/initializers/mcp_configurator.rb,
lib/claude_memory/commands/initializers/global_initializer.rb,
lib/claude_memory/commands/initializers/hooks_configurator.rb,
lib/claude_memory/commands/initializers/project_initializer.rb,
lib/claude_memory/commands/initializers/memory_instructions_writer.rb
Defined Under Namespace
Modules: Commands, Core, Distill, Domain, Embeddings, Hook, Index, Infrastructure, Ingest, Logging, MCP, Resolve, Store, Sweep Classes: CLI, Configuration, Error, Publish, Recall, Shortcuts
Constant Summary collapse
- SELF_CONTEXT_MARKER =
Context marker to prevent self-ingestion of ClaudeMemory’s own meta-conversations (distiller subagents, sweeper sessions, etc.). Include this marker in subagent prompts to exclude their transcripts from being ingested into the knowledge base.
"claude-memory-self"- VERSION =
"0.9.0"
Class Method Summary collapse
- .global_db_path(env = ENV) ⇒ Object
-
.logger ⇒ Logging::Logger, Logging::NullLogger
Module-level logger instance, shared across components.
-
.logger=(logger) ⇒ Object
Replace the module-level logger (useful for testing).
- .project_db_path(project_path = Dir.pwd) ⇒ Object
Class Method Details
.global_db_path(env = ENV) ⇒ Object
140 141 142 |
# File 'lib/claude_memory.rb', line 140 def self.global_db_path(env = ENV) Configuration.new(env).global_db_path end |
.logger ⇒ Logging::Logger, Logging::NullLogger
Module-level logger instance, shared across components
150 151 152 |
# File 'lib/claude_memory.rb', line 150 def self.logger @logger ||= Logging::Logger.new end |
.logger=(logger) ⇒ Object
Replace the module-level logger (useful for testing)
156 157 158 |
# File 'lib/claude_memory.rb', line 156 def self.logger=(logger) @logger = logger end |
.project_db_path(project_path = Dir.pwd) ⇒ Object
144 145 146 |
# File 'lib/claude_memory.rb', line 144 def self.project_db_path(project_path = Dir.pwd) Configuration.new.project_db_path(project_path) end |